@@ -199,8 +199,6 @@ enum {
 	PROP_MAX_WAIT,
 };
 
-static guint signals [LAST_SIGNAL] = { 0, };
-
 static void	gdm_xdmcp_manager_class_init	(GdmXdmcpManagerClass *klass);
 static void	gdm_xdmcp_manager_init	        (GdmXdmcpManager      *manager);
 static void	gdm_xdmcp_manager_finalize	(GObject	      *object);
@@ -1709,6 +1707,7 @@ gdm_xdmcp_display_alloc (GdmXdmcpManager         *manager,
 	d->handled          = TRUE;
 	d->tcp_disallowed   = FALSE;
 	d->vt               = -1;
+	d->vtnum            = -1;
 	d->x_servers_order  = -1;
 	d->logged_in        = FALSE;
 	d->login            = NULL;
