@@ -162,17 +162,6 @@ change_vt (int vt)
 	g_free (ret);
 }
 
-static int
-vector_len (char * const *v)
-{
-	int i;
-	if (v == NULL)
-		return 0;
-	for (i = 0; v[i] != NULL; i++)
-		;
-	return i;
-}
-
 static int
 get_vt_num (char **vec, char *vtpart, int depth)
 {
@@ -187,8 +176,10 @@ get_vt_num (char **vec, char *vtpart, int depth)
 	for (i = 0; vec[i] != NULL; i++) {
 		char **rvec;
 		rvec = g_strsplit (vec[i], ",", -1);
-		if (rvec == NULL || vector_len (rvec) != 3)
+		if (gdm_vector_len (rvec) != 3) {
+			g_strfreev (rvec);
 			continue;
+		}
 
 		if (strcmp (rvec[0], vtpart) == 0) {
 			/* could be nested? */
@@ -227,8 +218,10 @@ create_model (char **vec)
 		char **rvec;
 		int vt;
 		rvec = g_strsplit (vec[i], ",", -1);
-		if (rvec == NULL || vector_len (rvec) != 3)
+		if (gdm_vector_len (rvec) != 3) {
+			g_strfreev (rvec);
 			continue;
+		}
 
 		vt = get_vt_num (vec, rvec[2], 5);
 
@@ -562,8 +555,10 @@ check_for_users (void)
 		char **rvec;
 		int vt;
 		rvec = g_strsplit (vec[i], ",", -1);
-		if (rvec == NULL || vector_len (rvec) != 3)
+		if (gdm_vector_len (rvec) != 3) {
+			g_strfreev (rvec);
 			continue;
+		}
 
 		vt = get_vt_num (vec, rvec[2], 5);
 
