@@ -39,6 +39,10 @@
 #include "gdmconfig.h"
 #include "gdmuser.h"
 
+#include "gdm-common.h"
+#include "gdm-socket-protocol.h"
+#include "gdm-daemon-config-keys.h"
+
 #include "greeter.h"
 #include "greeter_item_ulist.h"
 #include "greeter_parser.h"
@@ -69,17 +73,21 @@ void
 greeter_item_ulist_check_show_userlist (void)
 {
 	/*
-	 * If there are no users, then hide the rectangle used to contain the
-	 * userlist.  This id allows a rectangle to be defined with alpha
+	 * If the browser feature isn't enabled or if there are no users,
+	 * then hide the rectangle used to contain the userlist.  The
+	 * userlist-rect id allows a rectangle to be defined with alpha
 	 * behind the userlist that also goes away when the list is empty.
 	 */
-	if (num_users == 0 && user_list != NULL) {
-		GreeterItemInfo *urinfo = greeter_lookup_id ("userlist-rect");
-		GnomeCanvasItem *item;
+	if (num_users == 0 || !gdm_config_get_bool (GDM_KEY_BROWSER)) {
 
-		gtk_widget_hide (user_list);
+		GreeterItemInfo *urinfo = greeter_lookup_id ("userlist-rect");
+
+		if (user_list != NULL)
+			gtk_widget_hide (user_list);
 
 		if (urinfo) {
+			GnomeCanvasItem *item;
+
 			if (urinfo->group_item != NULL)
 				item = GNOME_CANVAS_ITEM (urinfo->group_item);
 			else
@@ -137,8 +145,10 @@ check_for_displays (void)
 		char **rvec;
 
 		rvec = g_strsplit (vec[i], ",", -1);
-		if (rvec == NULL || ve_vector_len (rvec) != 3)
+		if (gdm_vector_len (rvec) != 3) {
+			g_strfreev (rvec);
 			continue;
+		}
 
 		g_hash_table_insert (displays_hash,
 				     g_strdup (rvec[1]),
@@ -181,9 +191,9 @@ greeter_populate_user_list (GtkTreeModel *tm)
 		gboolean    active;
 
 		if (usr->gecos && strcmp (usr->gecos, "") != 0) {
-			name = g_markup_escape_text (usr->gecos, -1);
+			name = gdm_common_text_to_escaped_utf8 (usr->gecos);
 		} else {
-			name = g_markup_escape_text (usr->login, -1);
+			name = gdm_common_text_to_escaped_utf8 (usr->login);
 		}
 
 		if (g_hash_table_lookup (displays_hash, usr->login))
@@ -214,7 +224,7 @@ greeter_populate_user_list (GtkTreeModel *tm)
 	}
 }
 
-void 
+void
 greeter_item_ulist_select_user (gchar *login)
 {
 	printf ("%c%c%c%s\n", STX, BEL,
@@ -259,12 +269,11 @@ browser_change_focus (GtkWidget *widget, GdkEventButton *event, gpointer data)
 }
 
 static void
-greeter_generate_userlist (GtkWidget *tv)
+greeter_generate_userlist (GtkWidget *tv, GreeterItemInfo *info)
 {
 	GtkTreeModel *tm;
 	GtkTreeViewColumn *column_one, *column_two;
 	GtkTreeSelection *selection;
-	GreeterItemInfo *info;
 	GList *list, *li;
 
 	gdm_greeter_users_init ();
@@ -302,9 +311,9 @@ greeter_generate_userlist (GtkWidget *tv)
 								       NULL);
 		gtk_tree_view_append_column (GTK_TREE_VIEW (tv), column_two);
 
-		greeter_populate_user_list (tm);
-
-		info = greeter_lookup_id ("userlist");
+		/* Only populate the user list if the browser is turned on */
+		if (gdm_config_get_bool (GDM_KEY_BROWSER))
+			greeter_populate_user_list (tm);
 
 		list = gtk_tree_view_column_get_cell_renderers (column_one);
 		for (li = list; li != NULL; li = li->next) {
@@ -378,7 +387,7 @@ greeter_item_ulist_setup (void)
 
 			force_no_tree_separators (user_list);
 
-			greeter_generate_userlist (user_list);
+			greeter_generate_userlist (user_list, info);
 
 			/* Reset size of the widget canvas item so it
 			 * is the same size as the userlist.  This
